@@ -1,10 +1,8 @@
 from .basic_delete import (BasicDeleteInteractor, BasicDeleteRequestModel)
 from .basic_get import (BasicGetInteractor, BasicGetRequestModel)
 from .basic_get_all import (BasicGetAllInteractor, BasicGetAllResponseModel)
-from .basic_post import (BasicPostInteractor, BasicPostRequestModel,
-                         SaveEntityException)
-from .basic_put import (BasicPutInteractor, BasicPutRequestModel,
-                        UpdateEntityException)
+from .basic_post import (BasicPostInteractor, BasicPostRequestModel, SaveEntityException)
+from .basic_put import (BasicPutInteractor, BasicPutRequestModel, UpdateEntityException)
 
 __all__ = ['BasicDeleteInteractor',
            'BasicDeleteRequestModel',
